DiplayApp library

Dependents:   mbed-os_Watson-IoT_ZXing_sample mbed-os_Watson-IoT_ZXing_sample GR-Boads_Camera_DisplayApp GR-Boads_Camera_DisplayApp ... more

For Windows PC

For Mac

Serial setting

You need to connect your PC and MicroUSB Connector(RZ/A1 Ch.0).

/media/uploads/dkato/usb0_and_button.jpg

Troubleshooting!

If your PC isn't Windows10, you need to install the specified driver from the below URL.
https://os.mbed.com/handbook/USBSerial

Unfortunately, since that is "Unsigned driver", you cannot install as is depending on your Windows version. Since the setting method is different for each PC, please search with "Unsigned driver" keyword on the search site.

トラブルシューティング!

Windows10以外ご使用の場合、ドライバのインストールが必要となります。下記サイトのからドライバーをダウンロードできます。
https://os.mbed.com/handbook/USBSerial

但し、「署名なしドライバ」となっていますので、お使いのWindowsバージョンによってはそのままインストールすることはできません。お使いのPC毎に設定方法が異なるため、検索サイトで「署名なしドライバ」で検索してください。

Revision:
5:6c04d9d15395
Parent:
4:3c46efbe6d21
--- a/DisplayApp.h	Tue Jun 13 12:16:47 2017 +0000
+++ b/DisplayApp.h	Thu Jun 21 09:54:13 2018 +0000
@@ -26,9 +26,9 @@
      *
      * @param   tsk_pri        Priority of the thread function. (default: osPriorityNormal).
      * @param   init_pri       Priority of before the USB is connected. (default: osPriorityLow).
      * @param   stack_size     stack size (in bytes) requirements for the thread function. (default: DEFAULT_STACK_SIZE).
      */
-    DisplayApp(osPriority tsk_pri = osPriorityNormal, uint32_t stack_size = DEFAULT_STACK_SIZE);
+    DisplayApp(osPriority tsk_pri = osPriorityNormal, uint32_t stack_size = 2048);
 
     /** Send RGB888 data
      *
@@ -26,9 +26,9 @@
      * @param   tsk_pri        Priority of the thread function. (default: osPriorityNormal).
      * @param   init_pri       Priority of before the USB is connected. (default: osPriorityLow).
-     * @param   stack_size     stack size (in bytes) requirements for the thread function. (default: DEFAULT_STACK_SIZE).
+     * @param   stack_size     stack size (in bytes) requirements for the thread function. (default: 2048).
      */